@@ -237,7 +237,7 @@ class SwaggerGenerator(Blueprint):
                 lk = k
         if preschema:
             if len(preschema) == 1:
-                if BaseModel.__subclasscheck__(preschema[lk][0].__class__):
+                if BaseModel.__subclasscheck__(preschema[lk][0]):
                     ss = preschema[k][0]
                 else:
                     ss = create_model(name, **preschema)
